==> ejc-zjkjcost-impl-3.0.0-20220627.071725-13-sources.jar: com/ejianc/business/zjkjcost/reserve/bean/PersonalApproveEntity.java <==
package com.ejianc.business.zjkjcost.reserve.bean;

import java.util.Date;
import java.math.*;
import java.util.List;
import java.util.ArrayList;
import java.io.Serializable;

import com.baomidou.mybatisplus.annotation.TableField;
import com.baomidou.mybatisplus.annotation.TableName;
import com.ejianc.framework.skeleton.template.BaseEntity;
import com.ejianc.framework.skeleton.template.annotation.SubEntity;

/**
 * 风险预留金-个人风险金过程返还、转抵审批表
 * 
 * @author generator
 * 
 */
 @TableName("ejc_zjkjcost_reserve_personal_approve")
public class PersonalApproveEntity extends BaseEntity {
    private static final long serialVersionUID = 1L;
    
    @TableField(value="bill_code")
    private String billCode; // 单据编号
    @TableField(value="bill_state")
    private Integer billState; // 单据状态（审批必须字段）
    @TableField(value="org_id")
    private Long orgId; // 项目部
    @TableField(value="org_name")
    private String orgName; // 项目部名称
    @TableField(value="org_code")
    private String orgCode; // 项目部编码
    @TableField(value="parent_org_id")
    private Long parentOrgId; // 组织
    @TableField(value="parent_org_name")
    private String parentOrgName; // 组织名称
    @TableField(value="parent_org_code")
    private String parentOrgCode; // 组织组织编码
    @TableField(value="employee_id")
    private Long employeeId; // 经办人
    @TableField(value="employee_name")
    private String employeeName; // 经办人名称
    @TableField(value="employee_time")
    private Date employeeTime; // 经办时间
    @TableField(value="department_id")
    private Long departmentId; // 经办部门
    @TableField(value="department_name")
    private String departmentName; // 经办部门名称
    @TableField(value="project_id")
    private Long projectId; // 项目ID
    @TableField(value="project_name")
    private String projectName; // 项目名称
    @TableField(value="project_code")
    private String projectCode; // 项目编号
    @TableField(value="turn_project_name")
    private String turnProjectName; // 拟转入现项目名称
    @TableField(value="applicant_id")
    private Long applicantId; // 申请人
    @TableField(value="applicant_name")
    private String applicantName; // 申请人名称
    @TableField(value="apply_clause")
    private String applyClause; // 申请事项
    @TableField(value="apply_clause_type")
    private Integer applyClauseType; // 申请事项（1-返还，2-转抵）
    @TableField(value="applicant_bank_accounts")
    private String applicantBankAccounts; // 申请人银行账户
    @TableField(value="applicant_phone")
    private String applicantPhone; // 申请人电话
    @TableField(value="opening_bank")
    private String openingBank; // 开户银行名称
    @TableField(value="project_Dept_opinion")
    private String projectDeptOpinion; // 项目部意见
    @TableField(value="finance_Dept_opinion")
    private String financeDeptOpinion; // 财务部意见
    @TableField(value="verify_mny")
    private BigDecimal verifyMny; // 核定额
    @TableField(value="actual_reserve_mny")
    private BigDecimal actualReserveMny; // 实际预留风险金额
    @TableField(value="remortgage_mny")
    private BigDecimal remortgageMny; // 转抵金额
    @TableField(value="reserve_balance_mny")
    private BigDecimal reserveBalanceMny; // 预留风险余额
    @TableField(value="finance__Dept_opinion")
    private String finance_deptOpinion; // 商务部意见
    @TableField(value="finance_remortgage_mny")
    private BigDecimal financeRemortgageMny; // 转抵金额(商务部)
    @TableField(value="finance_restitution_mny")
    private BigDecimal financeRestitutionMny; // 返还金额(商务部)
    @TableField(value="economy__Dept_opinion")
    private String economy_deptOpinion; // 经济部意见
    @TableField(value="economy_remortgage_mny")
    private BigDecimal economyRemortgageMny; // 转抵金额(经济部)
    @TableField(value="economy_restitution_mny")
    private BigDecimal economyRestitutionMny; // 返还金额(经济部)
    @TableField(value="general__Dept_opinion")
    private String general_deptOpinion; // 总经理意见
    @TableField(value="general_remortgage_mny")
    private BigDecimal generalRemortgageMny; // 转抵金额(总经理)
    @TableField(value="general_restitution_mny")
    private BigDecimal generalRestitutionMny; // 返还金额(总经理)
    
    
    

    public String getBillCode() {
        return billCode;
    }

    public void setBillCode(String billCode) {
        this.billCode = billCode;
    }
    public Integer getBillState() {
        return billState;
    }

    public void setBillState(Integer billState) {
        this.billState = billState;
    }
    public Long getOrgId() {
        return orgId;
    }

    public void setOrgId(Long orgId) {
        this.orgId = orgId;
    }
    public String getOrgName() {
        return orgName;
    }

    public void setOrgName(String orgName) {
        this.orgName = orgName;
    }
    public String getOrgCode() {
        return orgCode;
    }

    public void setOrgCode(String orgCode) {
        this.orgCode = orgCode;
    }
    public Long getParentOrgId() {
        return parentOrgId;
    }

    public void setParentOrgId(Long parentOrgId) {
        this.parentOrgId = parentOrgId;
    }
    public String getParentOrgName() {
        return parentOrgName;
    }

    public void setParentOrgName(String parentOrgName) {
        this.parentOrgName = parentOrgName;
    }
    public String getParentOrgCode() {
        return parentOrgCode;
    }

    public void setParentOrgCode(String parentOrgCode) {
        this.parentOrgCode = parentOrgCode;
    }
    public Long getEmployeeId() {
        return employeeId;
    }

    public void setEmployeeId(Long employeeId) {
        this.employeeId = employeeId;
    }
    public String getEmployeeName() {
        return employeeName;
    }

    public void setEmployeeName(String employeeName) {
        this.employeeName = employeeName;
    }
    public Date getEmployeeTime() {
        return employeeTime;
    }

    public void setEmployeeTime(Date employeeTime) {
        this.employeeTime = employeeTime;
    }
    public Long getDepartmentId() {
        return departmentId;
    }

    public void setDepartmentId(Long departmentId) {
        this.departmentId = departmentId;
    }
    public String getDepartmentName() {
        return departmentName;
    }

    public void setDepartmentName(String departmentName) {
        this.departmentName = departmentName;
    }
    public Long getProjectId() {
        return projectId;
    }

    public void setProjectId(Long projectId) {
        this.projectId = projectId;
    }
    public String getProjectName() {
        return projectName;
    }

    public void setProjectName(String projectName) {
        this.projectName = projectName;
    }
    public String getProjectCode() {
        return projectCode;
    }

    public void setProjectCode(String projectCode) {
        this.projectCode = projectCode;
    }
    public String getTurnProjectName() {
        return turnProjectName;
    }

    public void setTurnProjectName(String turnProjectName) {
        this.turnProjectName = turnProjectName;
    }
    public Long getApplicantId() {
        return applicantId;
    }

    public void setApplicantId(Long applicantId) {
        this.applicantId = applicantId;
    }
    public String getApplicantName() {
        return applicantName;
    }

    public void setApplicantName(String applicantName) {
        this.applicantName = applicantName;
    }
    public String getApplyClause() {
        return applyClause;
    }

    public void setApplyClause(String applyClause) {
        this.applyClause = applyClause;
    }
    public Integer getApplyClauseType() {
        return applyClauseType;
    }

    public void setApplyClauseType(Integer applyClauseType) {
        this.applyClauseType = applyClauseType;
    }
    public String getApplicantBankAccounts() {
        return applicantBankAccounts;
    }

    public void setApplicantBankAccounts(String applicantBankAccounts) {
        this.applicantBankAccounts = applicantBankAccounts;
    }
    public String getApplicantPhone() {
        return applicantPhone;
    }

    public void setApplicantPhone(String applicantPhone) {
        this.applicantPhone = applicantPhone;
    }
    public String getOpeningBank() {
        return openingBank;
    }

    public void setOpeningBank(String openingBank) {
        this.openingBank = openingBank;
    }
    public String getProjectDeptOpinion() {
        return projectDeptOpinion;
    }

    public void setProjectDeptOpinion(String projectDeptOpinion) {
        this.projectDeptOpinion = projectDeptOpinion;
    }
    public String getFinanceDeptOpinion() {
        return financeDeptOpinion;
    }

    public void setFinanceDeptOpinion(String financeDeptOpinion) {
        this.financeDeptOpinion = financeDeptOpinion;
    }
    public BigDecimal getVerifyMny() {
        return verifyMny;
    }

    public void setVerifyMny(BigDecimal verifyMny) {
        this.verifyMny = verifyMny;
    }
    public BigDecimal getActualReserveMny() {
        return actualReserveMny;
    }

    public void setActualReserveMny(BigDecimal actualReserveMny) {
        this.actualReserveMny = actualReserveMny;
    }
    public BigDecimal getRemortgageMny() {
        return remortgageMny;
    }

    public void setRemortgageMny(BigDecimal remortgageMny) {
        this.remortgageMny = remortgageMny;
    }
    public BigDecimal getReserveBalanceMny() {
        return reserveBalanceMny;
    }

    public void setReserveBalanceMny(BigDecimal reserveBalanceMny) {
        this.reserveBalanceMny = reserveBalanceMny;
    }
    public String getFinance_deptOpinion() {
        return finance_deptOpinion;
    }

    public void setFinance_deptOpinion(String finance_deptOpinion) {
        this.finance_deptOpinion = finance_deptOpinion;
    }
    public BigDecimal getFinanceRemortgageMny() {
        return financeRemortgageMny;
    }

    public void setFinanceRemortgageMny(BigDecimal financeRemortgageMny) {
        this.financeRemortgageMny = financeRemortgageMny;
    }
    public BigDecimal getFinanceRestitutionMny() {
        return financeRestitutionMny;
    }

    public void setFinanceRestitutionMny(BigDecimal financeRestitutionMny) {
        this.financeRestitutionMny = financeRestitutionMny;
    }
    public String getEconomy_deptOpinion() {
        return economy_deptOpinion;
    }

    public void setEconomy_deptOpinion(String economy_deptOpinion) {
        this.economy_deptOpinion = economy_deptOpinion;
    }
    public BigDecimal getEconomyRemortgageMny() {
        return economyRemortgageMny;
    }

    public void setEconomyRemortgageMny(BigDecimal economyRemortgageMny) {
        this.economyRemortgageMny = economyRemortgageMny;
    }
    public BigDecimal getEconomyRestitutionMny() {
        return economyRestitutionMny;
    }

    public void setEconomyRestitutionMny(BigDecimal economyRestitutionMny) {
        this.economyRestitutionMny = economyRestitutionMny;
    }
    public String getGeneral_deptOpinion() {
        return general_deptOpinion;
    }

    public void setGeneral_deptOpinion(String general_deptOpinion) {
        this.general_deptOpinion = general_deptOpinion;
    }
    public BigDecimal getGeneralRemortgageMny() {
        return generalRemortgageMny;
    }

    public void setGeneralRemortgageMny(BigDecimal generalRemortgageMny) {
        this.generalRemortgageMny = generalRemortgageMny;
    }
    public BigDecimal getGeneralRestitutionMny() {
        return generalRestitutionMny;
    }

    public void setGeneralRestitutionMny(BigDecimal generalRestitutionMny) {
        this.generalRestitutionMny = generalRestitutionMny;
    }
    
}

==> ejc-zjkjcost-impl-3.0.0-20221115.101851-98-sources.jar: com/ejianc/business/zjkjcost/reserve/bean/PersonalApproveEntity.java <==
package com.ejianc.business.zjkjcost.reserve.bean;

import java.util.Date;
import java.math.*;
import java.util.List;
import java.util.ArrayList;
import java.io.Serializable;

import com.baomidou.mybatisplus.annotation.TableField;
import com.baomidou.mybatisplus.annotation.TableName;
import com.ejianc.framework.skeleton.template.BaseEntity;
import com.ejianc.framework.skeleton.template.annotation.SubEntity;

/**
 * 风险预留金-个人风险金过程返还、转抵审批表
 * 
 * @author generator
 * 
 */
 @TableName("ejc_zjkjcost_reserve_personal_approve")
public class PersonalApproveEntity extends BaseEntity {
    private static final long serialVersionUID = 1L;

    @TableField(value="bill_code")
    private String billCode; // 单据编号
    @TableField(value="bill_state")
    private Integer billState; // 单据状态（审批必须字段）
    @TableField(value="org_id")
    private Long orgId; // 项目部
    @TableField(value="org_name")
    private String orgName; // 项目部名称
    @TableField(value="org_code")
    private String orgCode; // 项目部编码
    @TableField(value="parent_org_id")
    private Long parentOrgId; // 组织
    @TableField(value="parent_org_name")
    private String parentOrgName; // 组织名称
    @TableField(value="parent_org_code")
    private String parentOrgCode; // 组织组织编码
    @TableField(value="employee_id")
    private Long employeeId; // 经办人
    @TableField(value="employee_name")
    private String employeeName; // 经办人名称
    @TableField(value="employee_time")
    private Date employeeTime; // 经办时间
    @TableField(value="department_id")
    private Long departmentId; // 经办部门
    @TableField(value="department_name")
    private String departmentName; // 经办部门名称
    @TableField(value="project_id")
    private Long projectId; // 原项目ID
    @TableField(value="project_name")
    private String projectName; // 原项目名称
    @TableField(value="project_code")
    private String projectCode; // 原项目编号
    @TableField(value="turn_project_name")
    private String turnProjectName; // 拟转入现项目名称
    @TableField(value="applicant_id")
    private Long applicantId; // 申请人
    @TableField(value="applicant_name")
    private String applicantName; // 申请人名称
    @TableField(value="apply_clause")
    private String applyClause; // 申请事项
    @TableField(value="apply_clause_type")
    private Integer applyClauseType; // 申请事项（1-返还，2-转抵）
    @TableField(value="applicant_bank_accounts")
    private String applicantBankAccounts; // 申请人银行账户
    @TableField(value="applicant_phone")
    private String applicantPhone; // 申请人电话
    @TableField(value="opening_bank")
    private String openingBank; // 开户银行名称
    @TableField(value="project_dept_opinion")
    private String projectDeptOpinion; // 项目部意见
    @TableField(value="finance_dept_opinion")
    private String financeDeptOpinion; // 财务部意见
    @TableField(value="verify_mny")
    private BigDecimal verifyMny; // 核定额（财务部）
    @TableField(value="actual_reserve_mny")
    private BigDecimal actualReserveMny; // 实际预留（财务部）
    @TableField(value="remortgage_mny")
    private BigDecimal remortgageMny; // 已转抵（财务部）
    @TableField(value="reserve_balance_mny")
    private BigDecimal reserveBalanceMny; // 预留风险余额（财务部）
    @TableField(value="business_dept_opinion")
    private String businessDeptOpinion; // 商务部意见
    @TableField(value="business_remortgage_mny")
    private BigDecimal businessRemortgageMny; // 转抵/转低金额(商务部)
    @TableField(value="economy_dept_opinion")
    private String economyDeptOpinion; // 经济师意见
    @TableField(value="economy_remortgage_mny")
    private BigDecimal economyRemortgageMny; // 转抵/转低金额(经济师)
    @TableField(value="general_dept_opinion")
    private String generalDeptOpinion; // 总经理意见
    @TableField(value="general_remortgage_mny")
    private BigDecimal generalRemortgageMny; // 转抵/转低金额(总经理)

    public String getBillCode() {
        return billCode;
    }

    public void setBillCode(String billCode) {
        this.billCode = billCode;
    }

    public Integer getBillState() {
        return billState;
    }

    public void setBillState(Integer billState) {
        this.billState = billState;
    }

    public Long getOrgId() {
        return orgId;
    }

    public void setOrgId(Long orgId) {
        this.orgId = orgId;
    }

    public String getOrgName() {
        return orgName;
    }

    public void setOrgName(String orgName) {
        this.orgName = orgName;
    }

    public String getOrgCode() {
        return orgCode;
    }

    public void setOrgCode(String orgCode) {
        this.orgCode = orgCode;
    }

    public Long getParentOrgId() {
        return parentOrgId;
    }

    public void setParentOrgId(Long parentOrgId) {
        this.parentOrgId = parentOrgId;
    }

    public String getParentOrgName() {
        return parentOrgName;
    }

    public void setParentOrgName(String parentOrgName) {
        this.parentOrgName = parentOrgName;
    }

    public String getParentOrgCode() {
        return parentOrgCode;
    }

    public void setParentOrgCode(String parentOrgCode) {
        this.parentOrgCode = parentOrgCode;
    }

    public Long getEmployeeId() {
        return employeeId;
    }

    public void setEmployeeId(Long employeeId) {
        this.employeeId = employeeId;
    }

    public String getEmployeeName() {
        return employeeName;
    }

    public void setEmployeeName(String employeeName) {
        this.employeeName = employeeName;
    }

    public Date getEmployeeTime() {
        return employeeTime;
    }

    public void setEmployeeTime(Date employeeTime) {
        this.employeeTime = employeeTime;
    }

    public Long getDepartmentId() {
        return departmentId;
    }

    public void setDepartmentId(Long departmentId) {
        this.departmentId = departmentId;
    }

    public String getDepartmentName() {
        return departmentName;
    }

    public void setDepartmentName(String departmentName) {
        this.departmentName = departmentName;
    }

    public Long getProjectId() {
        return projectId;
    }

    public void setProjectId(Long projectId) {
        this.projectId = projectId;
    }

    public String getProjectName() {
        return projectName;
    }

    public void setProjectName(String projectName) {
        this.projectName = projectName;
    }

    public String getProjectCode() {
        return projectCode;
    }

    public void setProjectCode(String projectCode) {
        this.projectCode = projectCode;
    }

    public String getTurnProjectName() {
        return turnProjectName;
    }

    public void setTurnProjectName(String turnProjectName) {
        this.turnProjectName = turnProjectName;
    }

    public Long getApplicantId() {
        return applicantId;
    }

    public void setApplicantId(Long applicantId) {
        this.applicantId = applicantId;
    }

    public String getApplicantName() {
        return applicantName;
    }

    public void setApplicantName(String applicantName) {
        this.applicantName = applicantName;
    }

    public String getApplyClause() {
        return applyClause;
    }

    public void setApplyClause(String applyClause) {
        this.applyClause = applyClause;
    }

    public Integer getApplyClauseType() {
        return applyClauseType;
    }

    public void setApplyClauseType(Integer applyClauseType) {
        this.applyClauseType = applyClauseType;
    }

    public String getApplicantBankAccounts() {
        return applicantBankAccounts;
    }

    public void setApplicantBankAccounts(String applicantBankAccounts) {
        this.applicantBankAccounts = applicantBankAccounts;
    }

    public String getApplicantPhone() {
        return applicantPhone;
    }

    public void setApplicantPhone(String applicantPhone) {
        this.applicantPhone = applicantPhone;
    }

    public String getOpeningBank() {
        return openingBank;
    }

    public void setOpeningBank(String openingBank) {
        this.openingBank = openingBank;
    }

    public String getProjectDeptOpinion() {
        return projectDeptOpinion;
    }

    public void setProjectDeptOpinion(String projectDeptOpinion) {
        this.projectDeptOpinion = projectDeptOpinion;
    }

    public String getFinanceDeptOpinion() {
        return financeDeptOpinion;
    }

    public void setFinanceDeptOpinion(String financeDeptOpinion) {
        this.financeDeptOpinion = financeDeptOpinion;
    }

    public BigDecimal getVerifyMny() {
        return verifyMny;
    }

    public void setVerifyMny(BigDecimal verifyMny) {
        this.verifyMny = verifyMny;
    }

    public BigDecimal getActualReserveMny() {
        return actualReserveMny;
    }

    public void setActualReserveMny(BigDecimal actualReserveMny) {
        this.actualReserveMny = actualReserveMny;
    }

    public BigDecimal getRemortgageMny() {
        return remortgageMny;
    }

    public void setRemortgageMny(BigDecimal remortgageMny) {
        this.remortgageMny = remortgageMny;
    }

    public BigDecimal getReserveBalanceMny() {
        return reserveBalanceMny;
    }

    public void setReserveBalanceMny(BigDecimal reserveBalanceMny) {
        this.reserveBalanceMny = reserveBalanceMny;
    }

    public String getBusinessDeptOpinion() {
        return businessDeptOpinion;
    }

    public void setBusinessDeptOpinion(String businessDeptOpinion) {
        this.businessDeptOpinion = businessDeptOpinion;
    }

    public BigDecimal getBusinessRemortgageMny() {
        return businessRemortgageMny;
    }

    public void setBusinessRemortgageMny(BigDecimal businessRemortgageMny) {
        this.businessRemortgageMny = businessRemortgageMny;
    }

    public String getEconomyDeptOpinion() {
        return economyDeptOpinion;
    }

    public void setEconomyDeptOpinion(String economyDeptOpinion) {
        this.economyDeptOpinion = economyDeptOpinion;
    }

    public BigDecimal getEconomyRemortgageMny() {
        return economyRemortgageMny;
    }

    public void setEconomyRemortgageMny(BigDecimal economyRemortgageMny) {
        this.economyRemortgageMny = economyRemortgageMny;
    }

    public String getGeneralDeptOpinion() {
        return generalDeptOpinion;
    }

    public void setGeneralDeptOpinion(String generalDeptOpinion) {
        this.generalDeptOpinion = generalDeptOpinion;
    }

    public BigDecimal getGeneralRemortgageMny() {
        return generalRemortgageMny;
    }

    public void setGeneralRemortgageMny(BigDecimal generalRemortgageMny) {
        this.generalRemortgageMny = generalRemortgageMny;
    }
}
